@@ -320,15 +320,80 @@ class Logger:
         cls.handle_log_server(send_data=send_data)
 
 
-class MyLogger(logging.Logger):
-    app_name: str = None
-    host: str = None
-    extra_data: dict = None
+class LogstashHandler(logging.Handler):
+    """
+        A handler class which send data to logstash.
+    """
+    EXTRA_FIELDS = ['name', 'msg', 'args', 'levelname', 'levelno', 'pathname', 'filename', 'module', 'exc_info',
+                    'exc_text', 'stack_info', 'lineno', 'funcName', 'created', 'msecs', 'relativeCreated', 'thread',
+                    'threadName', 'processName', 'process', 'message']
+    LOGGER_DATA = ['name', 'levelname', 'levelno', 'pathname', 'filename', 'module', 'exc_info',
+                   'exc_text', 'stack_info', 'lineno', 'funcName', 'created', 'msecs', 'relativeCreated', 'thread',
+                   'threadName', 'processName', 'process']
 
-    log_level: int = INFO
-    log_format = '%(datetime)s %(level)s%(process_thread)s%(file_detail)s%(text)s'
+    def __init__(self, log_server: str, app_name: str = None, host_name: str = None, extra_data: dict = None):
+        super().__init__()
+        self.log_server = log_server
+        self.app_name = app_name
+        self.host_name = host_name
+        self.extra_data = extra_data
 
-    colorful: bool = True
+    def get_logger_data(self, record: "logging.LogRecord"):
+        """
+            Get some log data
+        """
+        logger_data = {}
+        for key in self.LOGGER_DATA:
+            logger_data[key] = getattr(record, key, None)
+        return logger_data
+
+    def get_send_data(self, record: logging.LogRecord):
+        send_data = {
+            "logger_data": self.get_logger_data(record=record),
+            "short_message": record.message,
+        }
+        if self.app_name is not None:
+            send_data["app_name"] = self.app_name
+        if self.host_name is not None:
+            send_data["host_name"] = self.host_name
+        if self.extra_data is not None:
+            send_data["extra_data"] = self.extra_data
+
+        record_dict = record.__dict__
+        for key in self.EXTRA_FIELDS:
+            if key in record_dict:
+                record_dict.pop(key)
+        for key, value in record_dict.items():
+            if str(key) not in ["logger_data", "extra_data", "short_message", "app_name", "host_name"]:
+                send_data[str(key)] = value
+        return send_data
+
+    def send(self, send_data: dict):
+        if not self.log_server:
+            return
+        urllib3_log = logging.getLogger("urllib3")
+        urllib3_log.setLevel(logging.CRITICAL)
+        urllib3_log.propagate = False
+        headers = {"Content-Type": "application/json"}
+        requests.post(self.log_server, json=send_data, headers=headers)
+
+    def emit(self, record: logging.LogRecord) -> None:
+        if not self.log_server:
+            return
+        try:
+            send_data = self.get_send_data(record=record)
+            self.send(send_data=send_data)
+
+        except RecursionError:  # See issue 36272
+            raise
+        except Exception:
+            self.handleError(record)
+
+
+class ColorfulStreamHandler(logging.StreamHandler):
+    """
+        A handler class which write stram handler.
+    """
     show_datetime: bool = True
     datetime_color: "Colors" = Colors.GREEN_F
 
@@ -354,10 +419,13 @@ class MyLogger(logging.Logger):
         DEBUG: ("DEBUG    ", Colors.BRIGHT_MAGENTA_F),
     }
 
-    log_server: str = None
-
-    def __init__(self, name: str, level=NOTSET):
-        super().__init__(name, level=level)
+    def __init__(self, log_format: str = None, colorful: bool = True):
+        super().__init__()
+        if log_format is None:
+            log_format = '%(datetime)s %(level)s%(process_thread)s%(file_detail)s%(text)s'
+        self.log_format = log_format
+        self.setFormatter(logging.Formatter(self.log_format))
+        self.colorful = colorful
 
     def get_color_text(self, text, color: Optional[Colors]):
         """
@@ -417,100 +485,49 @@ class MyLogger(logging.Logger):
         """
         return self.level_detail.get(record.levelno, ("", Colors.YELLOW_B))[1]
 
-    def makeRecord(self, name, level, fn, lno, msg, args, exc_info,
-                   func=None, extra=None, sinfo=None):
-        """
-        A factory method which can be overridden in subclasses to create
-        specialized LogRecords.
-        """
-        record = logging.getLogRecordFactory()(name, level, fn, lno, msg, args, exc_info, func, sinfo)
-        record.short_message = record.getMessage()
-        record.extra = extra
+    def emit(self, record: logging.LogRecord) -> None:
+        try:
+            record.message = record.getMessage()
+            record.datetime = self.get_color_text(self.get_datetime(), color=self.datetime_color)
+            record.process_thread = self.get_color_text(self.get_process_thread(record),
+                                                        color=self.process_thread_color)
+            record.file_detail = self.get_color_text(self.get_file_detail(record), color=self.file_color)
 
-        record.datetime = self.get_color_text(self.get_datetime(), color=self.datetime_color)
-        record.process_thread = self.get_color_text(self.get_process_thread(record), color=self.process_thread_color)
-        record.file_detail = self.get_color_text(self.get_file_detail(record), color=self.file_color)
+            color = self.get_level_color(record)
+            record.level = self.get_color_text(self.get_level(record), color=color)
+            record.text = self.get_color_text(record.message, color=color)
 
-        color = self.get_level_color(record)
-        record.level = self.get_color_text(self.get_level(record), color=color)
-        record.text = self.get_color_text(record.short_message, color=color)
+            message = self.format(record)
 
-        self.send_to_log_server(record=record)
-        return record
-
-    def get_send_data(self, record: "logging.LogRecord"):
-        """
-            Get some log data
-        """
-        return {
-            "level": record.levelno,
-            "line": record.lineno,
-            "file": record.filename,
-            "level_name": record.levelname,
-            "pathname": record.pathname,
-            "thread": record.thread,
-            "threadName": record.threadName,
-            "process": record.process,
-            "processName": record.processName,
-            "function": record.module,
-            "logger_name": record.name,
-            "created": record.created,
-            "msecs": record.msecs,
-        }
-
-    def handle_log_server(self, send_data):
-        """
-            For send data
-        """
-        log_server = []
-        if type(self.log_server) == str:
-            log_server = [self.log_server]
-        elif type(self.log_server) in [list, tuple]:
-            log_server = self.log_server
-
-        for server in log_server:
-            try:
-                headers = {"Content-Type": "application/json"}
-                data = json.dumps(send_data)
-                requests.post(server, data=data, headers=headers)
-            except Exception as e:
-                print_color(f"error in send data to log server {server}. Error: {e}, send_data: {send_data}",
-                            color=Colors.RED_F)
-
-    def send_to_log_server(self, record: "logging.LogRecord"):
-        """
-            Send Data to log server
-        """
-        if not self.log_server:
-            return
-        send_data = {
-            "short_message": getattr(record, "short_message", None),
-            "logger_data": self.get_send_data(record)
-        }
-        if self.app_name is not None:
-            send_data["app_name"] = self.app_name
-        if self.host is not None:
-            send_data["host_name"] = self.host
-        if self.extra_data is not None:
-            send_data["extra_data"] = self.extra_data
-        urllib3_log = logging.getLogger("urllib3")
-        urllib3_log.setLevel(logging.CRITICAL)
-        urllib3_log.propagate = False
-
-        extra = getattr(record, "extra", {}),
-        if type(extra) == dict:
-            for key, value in dict(extra).items():
-                if str(key) not in ["logger_data", "extra_data", "short_message", "app_name", "host_name"]:
-                    send_data[str(key)] = value
-
-        self.handle_log_server(send_data=send_data)
+            stream = self.stream
+            # issue 35046: merged two stream.writes into one.
+            stream.write(message + self.terminator)
+            self.flush()
+        except RecursionError:  # See issue 36272
+            raise
+        except Exception:
+            self.handleError(record)
 
 
-def set_logger(log_level: int = None, logger_class=MyLogger):
-    """
-        For get logger
-    """
-    logging.setLoggerClass(logger_class)
-    if log_level is None:
-        log_level = logger_class.log_level
-    logging.basicConfig(format=logger_class.log_format, level=log_level)
+# def set_logger():
+#     """
+#         For get logger
+#     """
+#     stream_handler = ColorfulStreamHandler()
+#     stream_handler.setLevel(logging.DEBUG)
+#     logging.root.addHandler(stream_handler)
+#     # todo add log handler
+#     # logger = logging.getLogger(__name__)
+#     logging.root.setLevel(logging.DEBUG)
+#     add_handler(logging.root)
+#
+#     # add_handler(logging.root)
+#     # add_handler(logging.root)
+#     # print(logging.root.name)
+#     # logstash_handler = LogstashHandler(log_server="8.8.8.8")
+#     # logstash_handler.setLevel(logging.DEBUG)
+#     # logging.root.addHandler(logstash_handler)
+#     # return logger
+#     # logging.setLoggerClass(logger_class)
+#     # logging.basicConfig(handlers=logger.handlers)
+#     # return logger
